#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_STRUCT_OSOCKADDR
#undef HAVE_LIBSM
#undef HAVE_LIBINTL_H
#undef HAVE_SA_LEN
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef GNOME_PILOT_MAJOR
#undef GNOME_PILOT_PATCHLEVEL
#undef GNOME_PILOT_REVISION
#undef GNOME_PILOT_VERSION
#undef PACKAGE
#undef VERSION
#undef USE_XOPEN_SOURCE
#undef GNOME_ICONDIR
#undef WITH_USB_VISOR
#undef WITH_IRDA
#undef WITH_NETWORK
#undef WITH_VFS
#undef GETTEXT_PACKAGE
